@@ -668,7 +668,7 @@ return_directory_response (struct MHD_Connection *connection)
  * @param upload_data data from upload (PUT/POST)
  * @param upload_data_size number of bytes in "upload_data"
  * @param ptr our context
- * @return MHD_YES on success, MHD_NO to drop connection
+ * @return #MHD_YES on success, #MHD_NO to drop connection
  */
 static int
 generate_page (void *cls,
@@ -693,12 +693,19 @@ generate_page (void *cls,
 
       if (0 != strcmp (method, MHD_HTTP_METHOD_GET))
 	return MHD_NO;  /* unexpected method (we're not polite...) */
-      if ( (0 == stat (&url[1], &buf)) &&
-	   (NULL == strstr (&url[1], "..")) &&
-	   ('/' != url[1]))
-	fd = open (&url[1], O_RDONLY);
-      else
-	fd = -1;
+      fd = -1;
+      if ( (NULL == strstr (&url[1], "..")) &&
+	   ('/' != url[1]) )
+        {
+          fd = open (&url[1], O_RDONLY);
+          if ( (-1 != fd) &&
+               ( (0 != fstat (fd, &buf)) ||
+                 (! S_ISREG (buf.st_mode)) ) )
+            {
+              (void) close (fd);
+              fd = -1;
+            }
+        }
       if (-1 == fd)
 	return MHD_queue_response (connection,
 				   MHD_HTTP_NOT_FOUND,
