@@ -27,6 +27,7 @@
 #include "internal.h"
 #include "md5.h"
 #include "mhd_mono_clock.h"
+#include "mhd_str.h"
 
 #if defined(_WIN32) && defined(MHD_W32_MUTEX_)
 #ifndef WIN32_LEAN_AND_MEAN
@@ -302,7 +303,7 @@ lookup_sub_value (char *dest,
  * @param connection The MHD connection structure
  * @param nonce A pointer that referenced a zero-terminated array of nonce
  * @param nc The nonce counter, zero to add the nonce to the array
- * @return MHD_YES if successful, MHD_NO if invalid (or we have no NC array)
+ * @return #MHD_YES if successful, #MHD_NO if invalid (or we have no NC array)
  */
 static int
 check_nonce_nc (struct MHD_Connection *connection,
@@ -313,6 +314,11 @@ check_nonce_nc (struct MHD_Connection *connection,
   uint32_t mod;
   const char *np;
 
+  if (MAX_NONCE_LENGTH <= strlen (nonce))
+    return MHD_NO; /* This should be impossible, but static analysis
+                      tools have a hard time with it *and* this also
+                      protects against unsafe modifications that may
+                      happen in the future... */
   mod = connection->daemon->nonce_nc_size;
   if (0 == mod)
     return MHD_NO; /* no array! */
@@ -334,8 +340,8 @@ check_nonce_nc (struct MHD_Connection *connection,
   (void) MHD_mutex_lock_ (&connection->daemon->nnc_lock);
   if (0 == nc)
     {
-      strcpy(connection->daemon->nnc[off].nonce,
-	     nonce);
+      strcpy (connection->daemon->nnc[off].nonce,
+              nonce);
       connection->daemon->nnc[off].nc = 0;
       (void) MHD_mutex_unlock_ (&connection->daemon->nnc_lock);
       return MHD_YES;
@@ -344,7 +350,7 @@ check_nonce_nc (struct MHD_Connection *connection,
        (0 != strcmp(connection->daemon->nnc[off].nonce, nonce)) )
     {
       (void) MHD_mutex_unlock_ (&connection->daemon->nnc_lock);
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
 		"Stale nonce received.  If this happens a lot, you should probably increase the size of the nonce array.\n");
 #endif
@@ -496,7 +502,7 @@ check_argument_match (struct MHD_Connection *connection,
   argb = strdup (args);
   if (NULL == argb)
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
 		"Failed to allocate memory for copy of URI arguments\n");
 #endif /* HAVE_MESSAGES */
@@ -657,7 +663,7 @@ MHD_digest_auth_check (struct MHD_Connection *connection,
        (0 == lookup_sub_value (nc, sizeof (nc), header, "nc"))  ||
        (0 == lookup_sub_value (response, sizeof (response), header, "response")) )
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
 		"Authentication failed, invalid format.\n");
 #endif
@@ -668,7 +674,7 @@ MHD_digest_auth_check (struct MHD_Connection *connection,
        ( (LONG_MAX == nci) &&
          (ERANGE == errno) ) )
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
 		"Authentication failed, invalid format.\n");
 #endif
@@ -691,7 +697,7 @@ MHD_digest_auth_check (struct MHD_Connection *connection,
     uri = malloc (left + 1);
     if (NULL == uri)
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG(connection->daemon,
                "Failed to allocate memory for auth header processing\n");
 #endif /* HAVE_MESSAGES */
@@ -730,7 +736,7 @@ MHD_digest_auth_check (struct MHD_Connection *connection,
 		      connection->url,
 		      strlen (connection->url)))
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
 		"Authentication failed, URI does not match.\n");
 #endif
@@ -749,7 +755,7 @@ MHD_digest_auth_check (struct MHD_Connection *connection,
 	  check_argument_match (connection,
 				args) )
       {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
 	MHD_DLOG (connection->daemon,
 		  "Authentication failed, arguments do not match.\n");
 #endif
@@ -800,7 +806,7 @@ MHD_queue_auth_fail_response (struct MHD_Connection *connection,
 		   nonce);
   if (MHD_YES != check_nonce_nc (connection, nonce, 0))
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG (connection->daemon,
 		"Could not register nonce (is the nonce array size zero?).\n");
 #endif
@@ -816,20 +822,21 @@ MHD_queue_auth_fail_response (struct MHD_Connection *connection,
 		   signal_stale
 		   ? ",stale=\"true\""
 		   : "");
+  if (hlen > 0)
   {
     char *header;
 
     header = malloc(hlen + 1);
     if (NULL == header)
     {
-#if HAVE_MESSAGES
+#ifdef HAVE_MESSAGES
       MHD_DLOG(connection->daemon,
                "Failed to allocate memory for auth response header\n");
 #endif /* HAVE_MESSAGES */
       return MHD_NO;
     }
 
-    MHD_snprintf_(header,
+    if (MHD_snprintf_(header,
 	      hlen + 1,
 	      "Digest realm=\"%s\",qop=\"auth\",nonce=\"%s\",opaque=\"%s\"%s",
 	      realm,
@@ -837,16 +844,28 @@ MHD_queue_auth_fail_response (struct MHD_Connection *connection,
 	      opaque,
 	      signal_stale
 	      ? ",stale=\"true\""
-	      : "");
-    ret = MHD_add_response_header(response,
+	      : "") == hlen)
+      ret = MHD_add_response_header(response,
 				  MHD_HTTP_HEADER_WWW_AUTHENTICATE,
 				  header);
+    else
+      ret = MHD_NO;
     free(header);
   }
+  else
+    ret = MHD_NO;
+
   if (MHD_YES == ret)
     ret = MHD_queue_response(connection,
 			     MHD_HTTP_UNAUTHORIZED,
 			     response);
+  else
+    {
+#ifdef HAVE_MESSAGES
+      MHD_DLOG (connection->daemon,
+                "Failed to add Digest auth header\n");
+#endif /* HAVE_MESSAGES */
+    }
   return ret;
 }
 
